#
# spec file for package mate-system-monitor
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 1.20
Name:           mate-system-monitor
Version:        1.20.0
Release:        lp150.1.2
Summary:        MATE Desktop system monitor
License:        GPL-2.0-or-later
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE mate-system-monitor-xdgsu.patch sor.alexei@meowr.ru -- Use xdg-su instead of gksu.
Patch0:         mate-system-monitor-xdgsu.patch
# PATCH-FEATURE-OPENSUSE mate-system-monitor-gtk-3.20.patch -- Restore GLib 2.48 and GTK+ 3.20 support.
Patch1:         mate-system-monitor-gtk-3.20.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  polkit
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(gtkmm-3.0) >= 3.20
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       polkit
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
Process viewer and system resource monitor for the MATE. This
package allows you to graphically view and manipulate the running
processes on your system. It also provides an overview of available
resources such as CPU and memory.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static                    \
  --disable-scrollkeeper              \
  --libexecdir=%{_libexecdir}/%{name} \
  --enable-systemd
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}.desktop
%fdupes %{buildroot}%{_datadir}/

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%glib2_gsettings_schema_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_libexecdir}/mate-system-monitor/
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/polkit-1/actions/*%{name}.policy
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}/
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_mandir}/man?/%{name}.?%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Avoid deprecated gdk_screen_width/height().
  * sysinfo: Avoid deprecated GtkAlignment.
  * Fix system logo alignment.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * process table: Make search case-insensitive.
  * procman.cpp: Fix "argument 1 null where non-null expected".
  * sysinfo.cpp: Fix "this 'if' clause does not guard..."
  * proctable.cpp: Fix "this 'else' clause does not guard..."
  * Update translations.
- Add mate-system-monitor-gtk-3.20.patch: Restore GLib 2.48 and
  GTK+ 3.20 support.
* Wed Oct 25 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * sysinfo: Disable focus in all labels.
  * Update copyright year.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Add pkexec support for using kill and renice on other users
    processes, and try using it before trying gksu.
  * Fix some GTK+ deprecations.
  * Update translations.
- Require polkit instead of xdg-utils but keep
  mate-system-monitor-xdgsu.patch just in case.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Update translations.
- Remove mate-system-monitor-gtk3.10.patch.
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Fix build with recent gcc and clang.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0 (changes since 1.12.2):
  * Move to GTK+3, drop GTK+2 code and --with-gtk build option.
  * Set minimum required GTK+ version to 3.14, drop some deprecated
    code.
  * Run gksu binary instead of loading libgksu2.so (which is GTK+2
    only).
  * Drop MateConf migration script.
  * Main window: Save maximised state in gsettings on exit and load
    it on startup.
  * Disks: Add saving and loading width and visibility of columns.
  * Process properties: Show cgroups.
  * Process properties: Show N/A when cgroups or selinux isn't set.
  * Process table: Show running state when CPU time changes.
  * Change graph grid line colours and pattern.
  * Draw the background of graphs explicitly to avoid issues with
    GTK+ 3.20.
  * Fix incorrect icons for some known applications like marco or
    vino.
  * Some more fixes and cleanups.
  * Update translations.
  * Fix Changelog generation.
- Rebase mate-system-monitor-xdgsu.patch.
- Add mate-system-monitor-gtk3.10.patch: add support for Gtk 3.10
  (SLE 12 and openSUSE 13.1).
* Mon Mar 21 2016 sor.alexei@meowr.ru
- Update to version 1.12.2:
  * Process table: Avoid expanding collapsed nodes on every refresh.
  * Prefs dialog: Fix refresh rate not saving in some cases.
  * Memmaps dialog: Fix unwanted autoscrolling to the top of list.
  * Fix segfault on view mode change with process properties open.
  * Some more fixes.
- Add mate-system-monitor-xdgsu.patch: use xdg-su instead of gksu.
- Require xdg-utils for privileging.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Build with systemd support.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Process table: delay saving column widths (avoids eating CPU
    and slowdowns when resizing columns).
  * Process table: force icon size (fixes huge mate-sensors-applet
    icon with recent Gtk3 versions).
  * Disks: set minimum width for device column (fixes crash when
    resizing it to zero with recent Gtk3 versions).
  * Some fixes and adjustments.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Support build with C++11.
* Thu Oct 15 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * SysInfo: Add proper detection for Linux Mint and LMDE.
  * SysInfo: Let distributions define custom side image.
  * Interface: Add border to notebook.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Add support for libsystemd (in addition to libsystemd-login).
  * Drop useless dependency on mate-icon-theme.
  * Drop C89 support.
  * Update translations.
* Mon Jul 13 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Help fixes.
  * Update translations.
* Tue May  5 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.2):
  * Update translations.
- Spec cleanup.
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  * Bugs fix release
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + Dont sync GSettings before quit; It is unneeded
    Closes #37 (https://github.com/mate-desktop/mate-system-monitor/issues/37)
  + Add appdata support
  + Update translations
* Mon Jul 14 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Fix man page NAME section
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + Add GTK3 support
  + Use libwnck instead of libmatewnck
  + Use yelp-tools instead of mate-doc-utils
- Remove unused dependencies: glibmm, giomm
- Replace libmatewnck requirement with libwnck
- Replace mate-doc-utils requirement with yelp-tools
* Thu Sep 19 2013 p.drouand@gmail.com
- Remove branded logo; it doesn't have real interest
* Sat Aug  3 2013 p.drouand@gmail.com
- Update to version 1.6.1
  + fix make file for automake-1.13
  + fixes for make dist
  + check if cpu color key exists before read it
    closes #14 https://github.com/mate-desktop/mate-system-monitor/issues/14
  + fix indentation
  + add manpage for mate-system-monitor
    closes #20 https://github.com/mate-desktop/mate-system-monitor/issues/20
* Wed Apr  3 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + AC_CONFIG_HEADERS to please automake 1.13
  +  Update mate-system-monitor.desktop.in.in
  * choose a unique name
  * add generic name
  + update translations
* Thu Jan 24 2013 nmo.marques@gmail.com
- Update to version 1.5.1
  + fix gsettings key names
  + gsettings schema translatable
  + add missing semi-colon to desktop file
  + fix first 5 original cpu colors
  + minor other fixes
- Remove mate-system-monitor-1.5.0-fix_desktop_file.patch,
  upstreamed
* Wed Nov  7 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + migrate to gsettings and drop all mateconf-2.0 stuff
  + fix POTFILES
- Add mate-system-monitor-1.5.0-fix_desktop_file.patch - fix
  desktop file, add missing semi-colon - merged upstream
- Add desktop database macros
* Mon Oct  1 2012 nmo.marques@gmail.com
- Add side-openSUSE.png: add openSUSE branded icon instead of the
  upstream ugly one!
* Sat Sep  8 2012 nmo.marques@gmail.com
- initial package from version 1.4.0
